@@ -1,8 +1,8 @@
-use std::path::PathBuf;
+use std::path::{Path, PathBuf};
 
 use walkdir::{DirEntry, WalkDir};
 
-fn is_with_prefix(entry: &DirEntry, prefix: &String) -> bool {
+fn is_with_prefix(entry: &DirEntry, prefix: &str) -> bool {
     entry
         .file_name()
         .to_str()
@@ -20,7 +20,7 @@ pub fn filter_by_prefix(path: PathBuf, prefix: String) -> Vec<PathBuf> {
     files
 }
 
-pub fn type_from_md_path(buf: &PathBuf) -> Option<String> {
+pub fn type_from_md_path(buf: &Path) -> Option<String> {
     let mut ancestors = buf.ancestors();
     ancestors.next()?;
     let typ = ancestors.next()?.file_name()?;
