@@ -1,4 +1,4 @@
 pub mod ast;
 pub mod errors;
-pub mod parser;
 pub mod quake;
+pub mod quake_parser;
